@@ -3,7 +3,7 @@ rgeo_env <- new.env(parent = emptyenv())
 .onLoad <- function(...) {
   maxmind_tags <- c("continent_name", "country_name", "country_code", "region_name",
                     "city_name", "timezone", "connection", "city_geoname_id", "latitude", "longitude",
-                    "isp", "organization", "asn", "aso", "postcode")
+                    "isp", "organization", "asn", "aso", "postcode","city_metro_code")
   ipinfo_tags <- c("hostname", "city", "region", "country",
                    "loc", "org", "postal", "phone")
   
